FeatureBlockingMode

Enum FeatureBlockingMode 

pub enum FeatureBlockingMode {
    Disabled = 0,
    AccelOver1p5g = 1,
    AccelOver1p5gOrHalfSlope = 2,
    AccelOver1p5gOrFullSlope = 3,
}
Shared blocking behavior used by flat and orientation detection.

Variants



Disabled = 0

Do not block state changes during large movements.



AccelOver1p5g = 1

Block when acceleration on any axis exceeds 1.5g.



AccelOver1p5gOrHalfSlope = 2

Block when acceleration exceeds 1.5g or slope exceeds half of the configured slope threshold.



AccelOver1p5gOrFullSlope = 3

Block when acceleration exceeds 1.5g or slope exceeds the configured slope threshold.