AltAccelConfig

Struct AltAccelConfig 

pub struct AltAccelConfig {
    pub mode: AccelMode,
    pub average: AverageSamples,
    pub odr: OutputDataRate,
}
Reduced accelerometer configuration used by the BMI323 alternate mode (6.1.2, Register (0x28) alt_acc_conf; 5.10).

Unlike AccelConfig, the alternate configuration does not contain bandwidth or range fields. The hardware only exposes mode, averaging, and output data rate in ALT_ACC_CONF.

Fields

mode: AccelMode

Sensor operating mode while the alternate configuration is active.

average: AverageSamples

Sample averaging depth used in the alternate configuration.

odr: OutputDataRate

Alternate output data rate.

Implementations

Source

impl AltAccelConfig

pub const fn to_word(self) -> u16

Encode the alternate configuration into the BMI323 register bit layout.