AltConfigControl

Struct AltConfigControl 

pub struct AltConfigControl {
    pub accel_enabled: bool,
    pub gyro_enabled: bool,
    pub reset_on_user_config_write: bool,
    pub switch_to_alternate: AltConfigSwitchSource,
    pub switch_to_user: AltConfigSwitchSource,
}
Automatic switching policy between user and alternate accel/gyro configurations.

Fields

accel_enabled: bool

Whether the accelerometer may switch to its alternate configuration.

gyro_enabled: bool

Whether the gyroscope may switch to its alternate configuration.

reset_on_user_config_write: bool

If enabled, any later write to ACC_CONF or GYR_CONF immediately returns the affected sensor to its user configuration.

switch_to_alternate: AltConfigSwitchSource

Feature-engine source that switches sensors into the alternate configuration.

switch_to_user: AltConfigSwitchSource

Feature-engine source that switches sensors back to the user configuration.