AltStatus

Struct AltStatus 

pub struct AltStatus(pub u16);
Current active accel/gyro configuration selection reported by the BMI323.

Tuple Fields

0: u16

Implementations

Source

impl AltStatus

pub const fn accel_uses_alternate(self) -> bool

Returns true when the accelerometer is currently using ALT_ACC_CONF.

pub const fn gyro_uses_alternate(self) -> bool

Returns true when the gyroscope is currently using ALT_GYR_CONF.