ErrorWord

Struct ErrorWord 

pub struct ErrorWord(pub u16);
Decoded contents of the BMI323 ERR_REG register.

Tuple Fields

0: u16

Implementations

Source

impl ErrorWord

pub const fn fatal(self) -> bool

Returns true if the BMI323 reports a fatal internal error.

pub const fn accel_conf_error(self) -> bool

Returns true if the current accelerometer configuration is invalid.

pub const fn gyro_conf_error(self) -> bool

Returns true if the current gyroscope configuration is invalid.