InterruptStatus

Struct InterruptStatus 

pub struct InterruptStatus(pub u16);
Decoded interrupt status for INT1, INT2, or I3C IBI (6.1.2, Registers (0x0D-0x0F) int_status_int1/int2/ibi).

Tuple Fields

0: u16

Implementations

Source

impl InterruptStatus

pub const fn no_motion(self) -> bool

Returns true if no-motion is asserted.

pub const fn any_motion(self) -> bool

Returns true if any-motion is asserted.

pub const fn flat(self) -> bool

Returns true if flat detection is asserted.

pub const fn orientation(self) -> bool

Returns true if orientation change is asserted.

pub const fn step_detector(self) -> bool

Returns true if the step detector event is asserted.

pub const fn step_counter(self) -> bool

Returns true if the step counter event is asserted.

pub const fn significant_motion(self) -> bool

Returns true if significant motion is asserted.

pub const fn tilt(self) -> bool

Returns true if tilt is asserted.

pub const fn tap(self) -> bool

Returns true if tap detection is asserted.

pub const fn i3c_sync(self) -> bool

Returns true if the I3C synchronization interrupt is asserted.

pub const fn error_status(self) -> bool

Returns true if the error-status interrupt is asserted.

This bit corresponds to err_status in the BMI323 INT_STATUS_INT1/2/IBI register (bit 10). It is mapped via InterruptSource::ErrorStatus.

pub const fn temp_data_ready(self) -> bool

Returns true if temperature data-ready is asserted.

pub const fn gyro_data_ready(self) -> bool

Returns true if gyroscope data-ready is asserted.

pub const fn accel_data_ready(self) -> bool

Returns true if accelerometer data-ready is asserted.

pub const fn fifo_watermark(self) -> bool

Returns true if FIFO watermark is asserted.

pub const fn fifo_full(self) -> bool

Returns true if FIFO full is asserted.