StatusWord

Struct StatusWord 

pub struct StatusWord(pub u16);
Decoded contents of the BMI323 STATUS register.

Tuple Fields

0: u16

Implementations

Source

impl StatusWord

pub const fn por_detected(self) -> bool

Returns true if the sensor reports a power-on reset condition.

pub const fn drdy_temp(self) -> bool

Returns true if a new temperature sample is available.

pub const fn drdy_gyro(self) -> bool

Returns true if a new gyroscope sample is available.

pub const fn drdy_accel(self) -> bool

Returns true if a new accelerometer sample is available.