AltConfigSwitchSource

Enum AltConfigSwitchSource 

pub enum AltConfigSwitchSource {
    None = 0,
    NoMotion = 1,
    AnyMotion = 2,
    Flat = 3,
    Orientation = 4,
    StepDetector = 5,
    StepCounter = 6,
    SignificantMotion = 7,
    Tilt = 8,
    Tap = 9,
}
Supported feature-engine sources that can switch between user and alternate sensor configurations.

The BMI323 datasheet describes these as switch sources A..I. This API names them by their corresponding feature interrupts instead.

Variants



None = 0

Disable automatic switching for this direction.



NoMotion = 1

Source A: no-motion.



AnyMotion = 2

Source B: any-motion.



Flat = 3

Source C: flat.



Orientation = 4

Source D: orientation.



StepDetector = 5

Source E: step detector.



StepCounter = 6

Source F: step-counter watermark.



SignificantMotion = 7

Source G: significant motion.



Tilt = 8

Source H: tilt.



Tap = 9

Source I: tap.