TapReportingMode

Enum TapReportingMode 

pub enum TapReportingMode {
    Immediate = 0,
    Confirmed = 1,
}
Reporting policy for tap gesture confirmation.

Variants



Immediate = 0

Report the gesture as soon as it is detected.



Confirmed = 1

Delay reporting until the configured gesture timeout confirms it.