pub struct AltConfigControl {
pub accel_enabled: bool,
pub gyro_enabled: bool,
pub reset_on_user_config_write: bool,
pub switch_to_alternate: AltConfigSwitchSource,
pub switch_to_user: AltConfigSwitchSource,
}Expand description
Automatic switching policy between user and alternate accel/gyro configurations.
Fields
accel_enabled: boolWhether the accelerometer may switch to its alternate configuration.
gyro_enabled: boolWhether the gyroscope may switch to its alternate configuration.
reset_on_user_config_write: boolIf enabled, any later write to ACC_CONF or GYR_CONF immediately
returns the affected sensor to its user configuration.
switch_to_alternate: AltConfigSwitchSourceFeature-engine source that switches sensors into the alternate configuration.
switch_to_user: AltConfigSwitchSourceFeature-engine source that switches sensors back to the user configuration.