pub struct AltStatus(pub u16);Expand description
Current active accel/gyro configuration selection reported by the BMI323.
Tuple Fields
0: u16Implementations
Sourceimpl AltStatus
impl AltStatus
Sourcepub const fn accel_uses_alternate(self) -> bool
pub const fn accel_uses_alternate(self) -> bool
Returns true when the accelerometer is currently using ALT_ACC_CONF.
Sourcepub const fn gyro_uses_alternate(self) -> bool
pub const fn gyro_uses_alternate(self) -> bool
Returns true when the gyroscope is currently using ALT_GYR_CONF.