pub struct ErrorWord(pub u16);Expand description
Decoded contents of the BMI323 ERR_REG register.
Tuple Fields
0: u16Implementations
Sourceimpl ErrorWord
impl ErrorWord
Sourcepub const fn accel_conf_error(self) -> bool
pub const fn accel_conf_error(self) -> bool
Returns true if the current accelerometer configuration is invalid.
Sourcepub const fn gyro_conf_error(self) -> bool
pub const fn gyro_conf_error(self) -> bool
Returns true if the current gyroscope configuration is invalid.