pub struct InterruptStatus(pub u16);Expand description
Decoded interrupt status for INT1, INT2, or I3C IBI
(6.1.2, Registers (0x0D-0x0F) int_status_int1/int2/ibi).
Tuple Fields
0: u16Implementations
Sourceimpl InterruptStatus
impl InterruptStatus
Sourcepub const fn any_motion(self) -> bool
pub const fn any_motion(self) -> bool
Returns true if any-motion is asserted.
Sourcepub const fn orientation(self) -> bool
pub const fn orientation(self) -> bool
Returns true if orientation change is asserted.
Sourcepub const fn step_detector(self) -> bool
pub const fn step_detector(self) -> bool
Returns true if the step detector event is asserted.
Sourcepub const fn step_counter(self) -> bool
pub const fn step_counter(self) -> bool
Returns true if the step counter event is asserted.
Sourcepub const fn significant_motion(self) -> bool
pub const fn significant_motion(self) -> bool
Returns true if significant motion is asserted.
Sourcepub const fn i3c_sync(self) -> bool
pub const fn i3c_sync(self) -> bool
Returns true if the I3C synchronization interrupt is asserted.
Sourcepub const fn error_status(self) -> bool
pub const fn error_status(self) -> bool
Returns true if the error-status interrupt is asserted.
This bit corresponds to err_status in the BMI323 INT_STATUS_INT1/2/IBI
register (bit 10). It is mapped via InterruptSource::ErrorStatus.
Sourcepub const fn temp_data_ready(self) -> bool
pub const fn temp_data_ready(self) -> bool
Returns true if temperature data-ready is asserted.
Sourcepub const fn gyro_data_ready(self) -> bool
pub const fn gyro_data_ready(self) -> bool
Returns true if gyroscope data-ready is asserted.
Sourcepub const fn accel_data_ready(self) -> bool
pub const fn accel_data_ready(self) -> bool
Returns true if accelerometer data-ready is asserted.
Sourcepub const fn fifo_watermark(self) -> bool
pub const fn fifo_watermark(self) -> bool
Returns true if FIFO watermark is asserted.